==> gedit2-1.113.0.tar.gz: gedit-1.113.0/src/dialogs/gedit-dialogs.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * gedit-dialogs.h
 * This file is part of gedit
 *
 * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
 * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi 
 * Copyright (C) 2002  Paolo Maggi 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA.
 */
 
/*
 * Modified by the gedit Team, 1998-2002. See the AUTHORS file for a 
 * list of people on the gedit Team.  
 * See the ChangeLog files for a list of changes. 
 */

#ifndef __GEDIT_DIALOGS_H__
#define __GEDIT_DIALOGS_H__

#include <gtk/gtkwindow.h>

void gedit_dialog_goto_line (void);
void gedit_dialog_find 	    (void);
void gedit_dialog_replace   (void);

void gedit_dialog_open_uri  (void);

void gedit_dialog_plugin_manager (void);

gchar *gedit_plugin_program_location_dialog (gchar *program_name, 
					     gchar *plugin_name, 
					     GtkWindow *parent);

#endif /* __GEDIT_DIALOGS_H__ */

==> gedit-2.2.2.tar.gz: gedit-2.2.2/src/dialogs/gedit-dialogs.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * gedit-dialogs.h
 * This file is part of gedit
 *
 * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
 * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi 
 * Copyright (C) 2002  Paolo Maggi 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA.
 */
 
/*
 * Modified by the gedit Team, 1998-2002. See the AUTHORS file for a 
 * list of people on the gedit Team.  
 * See the ChangeLog files for a list of changes. 
 */

#ifndef __GEDIT_DIALOGS_H__
#define __GEDIT_DIALOGS_H__

#include <gtk/gtkwindow.h>

GQuark gedit_was_wrap_around_quark (void);

void gedit_dialog_goto_line (void);
void gedit_dialog_find 	    (void);
void gedit_dialog_replace   (void);

void gedit_dialog_open_uri  (void);

gchar *gedit_plugin_program_location_dialog (const gchar *program_name, 
					     const gchar *plugin_name, 
					     GtkWindow *parent);

#endif /* __GEDIT_DIALOGS_H__ */
